<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Nivel %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Sin carátula</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Introduzca la nueva extensión:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Crear una nueva extensión</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Directorio que contiene los vídeos</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Este directorio debe de existir, y el usuario de MythVideo debe de tener permiso de lectura en él.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Nivel de acceso inicial</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - Alto</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Bajo</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>Este es el nivel de acceso con el que se inicia MythVideo. Cualquier video con un nivel inferior, se listará. Para cambiar este nivel será necesario introducir el PIN.</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>PIN de control de acceso</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Si se activa, no podrá volver a esta pantalla sin volver a introducir su PIN. Está avisado.</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Visualizar ficheros de tipo desconocido</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Si esta activo, todos los ficheros por debajo del directorio de MythVideo serán visualizados excepto los que tengan una extensión que explícitamente los oculte.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>La Lista de Vídeos lista ficheros</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Si se activa, la Lista de Vídeos visualizará cualquier archivo encontrado a partir del directorio inicial de MythVideo.</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Configuración de reproducción</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">PIN de acceso:</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Sin carátula</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation type="obsolete">Sin clasificar</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Reproductor por defecto</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>Los ficheros nuevos son listados por defecto</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation>Si está activado, los nuevos ficheros serán marcados como listables y aparecerán en el menú &apos;Navegación&apos;.</translation>
    </message>
    <message>
        <source>New category</source>
        <translation>Nueva categoría</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation>Este PIN es usado para controlar el nivel de control de acceso. Si desea usar esta función, ajustar el valor a  todos los números le hará la vida mucho más fácil.</translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>Comando para buscar listados de películas</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation>Este comando debe ser ejecutable para el usuario corriendo MythVideo.</translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>Comando para buscar posters</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>Comando para extraer datos de películas</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>Directorio que guarda los posters</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation>El directorio debe existir, y el usuario que ejecuta MythVideo necesita tener permisos de lectura/escritura.</translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>Gestor Vídeos</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>No se descargó el poster</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>Un poster existe para esta película pero Myhn no ha podido descargarlo en un tiempo razonable.
</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>Vista por defecto</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galería</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Navegador</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>Listado</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>Control Acceso Agresivo</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation>Este es el comando usado para cualquier fichero cuya extensión no esté específicamente definida. También puede entrar el nombre de uno de los plugins internos como &apos;Internal&apos;.</translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>Filas a mostrar</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>Columnas a mostrar</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>Mostrar título debajo de miniaturas</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation>Si está activado, el texto adicional hará las miniaturas más pequeñas.</translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>Mantener relación de aspecto de las miniaturas</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation>Si está activado, las miniaturas mantendrán la relación de aspecto original. Si no está activado, se escalarán para ajustarse al tamaño del icono de fondo.</translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>Galería de Vídeos</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation>La vista por defecto de MythVideo. Otras vistas pueden ser seleccionadas por el menú emergente de la tecla MENU.</translation>
    </message>
    <message>
        <source>Video Browser browses files</source>
        <translation>El Navegador lista ficheros</translation>
    </message>
    <message>
        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Si está activado, el Navegador mostrará ficheros aunque no hayan sido escaneados.</translation>
    </message>
    <message>
        <source>Video Gallery browses files</source>
        <translation>La Galería lista ficheros</translation>
    </message>
    <message>
        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Si está activado, la Galería mostrará ficheros aunque no hayan sido escaneados.</translation>
    </message>
    <message>
        <source>General Settings (1/2)</source>
        <translation>Configuración General (1/2)</translation>
    </message>
    <message>
        <source>General Settings (2/2)</source>
        <translation>Configuración General (2/2)</translation>
    </message>
    <message>
        <source>Video List Loads Video Meta Data</source>
        <translation>La Lista Videos carga metadatos</translation>
    </message>
    <message>
        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
        <translation>Sí se activa junto con Listar Ficheros, esto causará que la Lista Videos cargue cualquier metadato conocido desde la base de datos. Desactivarlo acelerará la carga del árbol Lista Videos</translation>
    </message>
    <message>
        <source>Sorting ignores case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, case is ignored when sorting entries in a view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show folders for database views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, sub folders of your video directory will be shown in supported views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image cache size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting determines the number of images MythVideo will cache for views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>^(The |A |An )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Todos</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Si</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished">Año</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished">Puntuación</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished">Duración</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Director:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Año:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Clasificación:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Nivel de acceso:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Resumen:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Nombre del archivo:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Carátula:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>obteniendo información...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ buscando ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Introducir IMDB #</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>cargando...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>No encuentro vídeos</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Director</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Archivo:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Asociación de archivos a MythVideo</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Extensión:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Reproductor:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignorar:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Editar Información del video</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Nível de Acceso:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Archivo a reproducir después:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Incluir al listar:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Imagen de portada:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Commande de lecture:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/directorio/para/la/imagen.jpg</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Listable:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>Núm. IMDB:</translation>
    </message>
    <message>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <source>PL </source>
        <translation></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Filtrar lista vídeos</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Categoría :</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Género :</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>País :</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>Año :</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Duración :</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Puntuación :</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>Listar :</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Ordenar :</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>ENTER: Editar</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Acceso</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Año</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - Menú acción</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Arriba/Abajo, Página Arriba/Abajo: Navegar   MENU: Opciones   INFO: Menú acciones</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Reproducir fichero después:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 de %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>No hay vídeos</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Clasificación no disponible.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutos</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Ver este Vídeo</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Ver Info Completa</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Cambiar a Vista Navegador</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Cambiar a Vista Galería</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Cambiar a Vista Lista</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Seleccione acción</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">PIN Acceso:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Resultado de este filtro : %1 vídeo(s)</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Resultado de este filtro: Ninguno</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconocido</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="obsolete">Todos</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Guardar por defecto</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Ver este Vídeo</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Ver Info Completa</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Ver Detalles</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Especificar manualmente el IMDB#</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutos</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Si</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Sin carátula</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconocido</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Ninguno</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>borrado fallido</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Seleccione acción:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Editar Metadatos</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Buscar IMDB</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Borrar Metadatos</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation>No listar</translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Borrar Vídeo</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>¿Borrar este fichero?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Clasificación no disponible.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutos</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Pin de control de acceso:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Seleccione acción</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Ver este Vídeo</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Ver Info Completa</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Cambiar a Vista Navegador</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Cambiar a Vista Galería</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation></translation>
    </message>
</context>
</TS>
